@@ -1,9 +1,15 @@
 use std::{convert::TryFrom, env};
 
 use miette::{GraphicalTheme, IntoDiagnostic, Result};
-use mit_commit_message_lints::{external::Git2, mit::get_commit_coauthor_configuration};
+use mit_commit_message_lints::{
+    external::Git2,
+    mit::{get_commit_coauthor_configuration, AuthorState},
+};
 
-use crate::{cli::app, errors::StaleAuthorError};
+use crate::{
+    cli::app,
+    errors::{NoAuthorError, StaleAuthorError},
+};
 
 fn main() -> Result<()> {
     if env::var("DEBUG_PRETTY_ERRORS").is_ok() {
@@ -24,8 +30,12 @@ fn main() -> Result<()> {
     let mut git_config = Git2::try_from(current_dir)?;
     let co_author_configuration = get_commit_coauthor_configuration(&mut git_config)?;
 
-    if !co_author_configuration.is_some() {
-        return Err(StaleAuthorError {}.into());
+    if let AuthorState::Timeout(time) = co_author_configuration {
+        return Err(StaleAuthorError::new(time).into());
+    }
+
+    if co_author_configuration.is_none() {
+        return Err(NoAuthorError {}.into());
     }
 
     Ok(())
